==> xlniuxdata_developerplatform-1.0.0-20160226.061030-8-sources.jar: com/xunlei/niux/data/developerplatform/vo/DeveloperGamesIncome.java <==
package com.xunlei.niux.data.developerplatform.vo;

import com.ferret.common.dao.annotation.Table;

import java.math.BigDecimal;

@Table(tableName="developer_games_income",pkFieldName="seqid",pkFieldAssign=false)
public class DeveloperGamesIncome {

    private Long seqid;
    private String incomeDate;
    private String gameId;
    private String gameName;
    private BigDecimal incomeTotal;
    private BigDecimal incomeTest;
    private BigDecimal incomeCash;
    private BigDecimal incomeCoin;
    private BigDecimal incomePay;
    private BigDecimal incomeXunlei;
    private BigDecimal incomePartner;
    private Integer incomeStatus;
    private String editBy;

    public BigDecimal getIncomeCoin() {
        return incomeCoin;
    }

    public void setIncomeCoin(BigDecimal incomeCoin) {
        this.incomeCoin = incomeCoin;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getIncomeDate() {
        return incomeDate;
    }

    public void setIncomeDate(String incomeDate) {
        this.incomeDate = incomeDate;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getGameName() {
        return gameName;
    }

    public void setGameName(String gameName) {
        this.gameName = gameName;
    }

    public BigDecimal getIncomeTotal() {
        return incomeTotal;
    }

    public void setIncomeTotal(BigDecimal incomeTotal) {
        this.incomeTotal = incomeTotal;
    }

    public BigDecimal getIncomeTest() {
        return incomeTest;
    }

    public void setIncomeTest(BigDecimal incomeTest) {
        this.incomeTest = incomeTest;
    }

    public BigDecimal getIncomeCash() {
        return incomeCash;
    }

    public void setIncomeCash(BigDecimal incomeCash) {
        this.incomeCash = incomeCash;
    }

    public BigDecimal getIncomePay() {
        return incomePay;
    }

    public void setIncomePay(BigDecimal incomePay) {
        this.incomePay = incomePay;
    }

    public BigDecimal getIncomeXunlei() {
        return incomeXunlei;
    }

    public void setIncomeXunlei(BigDecimal incomeXunlei) {
        this.incomeXunlei = incomeXunlei;
    }

    public BigDecimal getIncomePartner() {
        return incomePartner;
    }

    public void setIncomePartner(BigDecimal incomePartner) {
        this.incomePartner = incomePartner;
    }

    public Integer getIncomeStatus() {
        return incomeStatus;
    }

    public void setIncomeStatus(Integer incomeStatus) {
        this.incomeStatus = incomeStatus;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    private String editTime;
}

==> xlniuxdata_developerplatform-1.0.0-20160906.035735-27-sources.jar: com/xunlei/niux/data/developerplatform/vo/DeveloperGamesIncome.java <==
package com.xunlei.niux.data.developerplatform.vo;

import com.ferret.common.dao.annotation.Table;

import java.math.BigDecimal;

@Table(tableName="developer_games_income",pkFieldName="seqid",pkFieldAssign=false)
public class DeveloperGamesIncome {

    private Long seqid;
    private String incomeDate;
    private String gameId;
    private String gameName;
    private BigDecimal incomeTotal;
    private BigDecimal incomeTest;
    private BigDecimal incomeCash;
    private BigDecimal incomeCoin;
    private BigDecimal incomePay;
    private BigDecimal incomeXunlei;
    private BigDecimal incomePartner;
    private Integer incomeStatus;
    private String editBy;
    private Long infoId;
    private String enterpriseName;

    public Long getInfoId() {
        return infoId;
    }

    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }

    public String getEnterpriseName() {
        return enterpriseName;
    }

    public void setEnterpriseName(String enterpriseName) {
        this.enterpriseName = enterpriseName;
    }

    public BigDecimal getIncomeCoin() {
        return incomeCoin;
    }

    public void setIncomeCoin(BigDecimal incomeCoin) {
        this.incomeCoin = incomeCoin;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getIncomeDate() {
        return incomeDate;
    }

    public void setIncomeDate(String incomeDate) {
        this.incomeDate = incomeDate;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getGameName() {
        return gameName;
    }

    public void setGameName(String gameName) {
        this.gameName = gameName;
    }

    public BigDecimal getIncomeTotal() {
        return incomeTotal;
    }

    public void setIncomeTotal(BigDecimal incomeTotal) {
        this.incomeTotal = incomeTotal;
    }

    public BigDecimal getIncomeTest() {
        return incomeTest;
    }

    public void setIncomeTest(BigDecimal incomeTest) {
        this.incomeTest = incomeTest;
    }

    public BigDecimal getIncomeCash() {
        return incomeCash;
    }

    public void setIncomeCash(BigDecimal incomeCash) {
        this.incomeCash = incomeCash;
    }

    public BigDecimal getIncomePay() {
        return incomePay;
    }

    public void setIncomePay(BigDecimal incomePay) {
        this.incomePay = incomePay;
    }

    public BigDecimal getIncomeXunlei() {
        return incomeXunlei;
    }

    public void setIncomeXunlei(BigDecimal incomeXunlei) {
        this.incomeXunlei = incomeXunlei;
    }

    public BigDecimal getIncomePartner() {
        return incomePartner;
    }

    public void setIncomePartner(BigDecimal incomePartner) {
        this.incomePartner = incomePartner;
    }

    public Integer getIncomeStatus() {
        return incomeStatus;
    }

    public void setIncomeStatus(Integer incomeStatus) {
        this.incomeStatus = incomeStatus;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    private String editTime;
}
